test suite reviews and discussions
 help / color / mirror / Atom feed
* [dts] [PATCH V1] ipfrag_ipfrag_fragment modify the max length of packet
@ 2019-01-17  2:18 zhuwenhui
  2019-01-17  8:04 ` Yao, BingX Y
  2019-01-21  6:33 ` Tu, Lijuan
  0 siblings, 2 replies; 3+ messages in thread
From: zhuwenhui @ 2019-01-17  2:18 UTC (permalink / raw)
  To: dts; +Cc: zhuwenhui

Original each packet max len:  1452,
current code 7a838c8798a93f changed to aligned to 8 bytes, len is 1456

Signed-off-by: zhuwenhui <wenhuix.zhu@intel.com>
---
 tests/TestSuite_ipfrag.py | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/tests/TestSuite_ipfrag.py b/tests/TestSuite_ipfrag.py
index 38e00d7..3a9ffb8 100644
--- a/tests/TestSuite_ipfrag.py
+++ b/tests/TestSuite_ipfrag.py
@@ -200,9 +200,9 @@ l3fwd_ipv4_route_array[] = {\\\n"
         for size in pkt_sizes[::burst]:
             # simulate to set TG properties
             if flag == 'frag':
-                # each packet max len: 1518 - 18 (eth) - 40 (ipv6) - 8 (ipv6 ext hdr) = 1452
-                expPkts = (size - HEADER_SIZE['eth'] - HEADER_SIZE['ipv6']) / 1452
-                if (size - HEADER_SIZE['eth'] - HEADER_SIZE['ipv6']) % 1452:
+                # each packet max len: 1522 - 18 (eth) - 40 (ipv6) - 8 (ipv6 ext hdr) = 1456
+                expPkts = (size - HEADER_SIZE['eth'] - HEADER_SIZE['ipv6']) / 1456
+                if (size - HEADER_SIZE['eth'] - HEADER_SIZE['ipv6']) % 1456:
                     expPkts += 1
                 val = 0
             else:
@@ -240,7 +240,7 @@ l3fwd_ipv4_route_array[] = {\\\n"
 
                     # fragment offset should be correct
                     frag = pkt.strip_element_layer4("offset")
-                    self.verify((frag == int((idx - 1) * 181.5)), "Fragment packet frag not match")
+                    self.verify((frag == int((idx - 1) * 182)), "Fragment packet frag not match")
                     idx += 1
 
     def set_up(self):
-- 
2.17.2

^ permalink raw reply	[flat|nested] 3+ messages in thread

end of thread, other threads:[~2019-01-21  6:33 UTC | newest]

Thread overview: 3+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2019-01-17  2:18 [dts] [PATCH V1] ipfrag_ipfrag_fragment modify the max length of packet zhuwenhui
2019-01-17  8:04 ` Yao, BingX Y
2019-01-21  6:33 ` Tu, Lijuan

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).